@@ -100,8 +100,8 @@ class EndpointOperation:
     response_type: type
     http_method: HTTPMethod
     public: bool
-    request_examples: Optional[List[Any]]
-    response_examples: Optional[List[Any]]
+    request_examples: Optional[List[Any]] = None
+    response_examples: Optional[List[Any]] = None
 
     def get_route(self) -> str:
         if self.route is not None:
@@ -118,10 +118,10 @@ class _FormatParameterExtractor:
 
     keys: List[str]
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.keys = []
 
-    def __getitem__(self, key: str):
+    def __getitem__(self, key: str) -> None:
         self.keys.append(key)
         return None
 
@@ -135,7 +135,6 @@ def _get_route_parameters(route: str) -> List[str]:
 def _get_endpoint_functions(
     endpoint: type, prefixes: List[str]
 ) -> Iterator[Tuple[str, str, str, Callable]]:
-
     if not inspect.isclass(endpoint):
         raise ValidationError(f"object is not a class type: {endpoint}")
 
@@ -162,7 +161,9 @@ def _get_defining_class(member_fn: str, derived_cls: type) -> type:
     )
 
 
-def get_endpoint_operations(endpoint: type) -> List[EndpointOperation]:
+def get_endpoint_operations(
+    endpoint: type, use_examples: bool = True
+) -> List[EndpointOperation]:
     """
     Extracts a list of member functions in a class eligible for HTTP interface binding.
 
@@ -179,6 +180,7 @@ def get_endpoint_operations(endpoint: type) -> List[EndpointOperation]:
     and the caller is expected to provide the data as serialized JSON in an HTTP POST request.
 
     :param endpoint: A class with member functions that can be mapped to an HTTP endpoint.
+    :param use_examples: Whether to return examples associated with member functions.
     """
 
     result = []
@@ -197,7 +199,6 @@ def get_endpoint_operations(endpoint: type) -> List[EndpointOperation]:
             "update",
         ],
     ):
-
         # extract routing information from function metadata
         webmethod: Optional[WebMethod] = getattr(func_ref, "__webmethod__", None)
         if webmethod is not None:
@@ -234,7 +235,7 @@ def get_endpoint_operations(endpoint: type) -> List[EndpointOperation]:
                 )
 
             if is_type_optional(param_type):
-                inner_type = unwrap_optional_type(param_type)
+                inner_type: type = unwrap_optional_type(param_type)
             else:
                 inner_type = param_type
 
@@ -325,8 +326,8 @@ def get_endpoint_operations(endpoint: type) -> List[EndpointOperation]:
                 response_type=response_type,
                 http_method=http_method,
                 public=public,
-                request_examples=request_examples,
-                response_examples=response_examples,
+                request_examples=request_examples if use_examples else None,
+                response_examples=response_examples if use_examples else None,
             )
         )
 
